ImageView

Struct ImageView 

pub struct ImageView { /* private fields */ }
ImageView are specialized views in visualizing images and GIF animations.

Remark

This type is managed by nappgui itself. Rust does not have its ownership. When the window object is dropped, all components assciated with it will be automatically released.

Implementations

Source

impl ImageView

pub fn new(width: f32, height: f32) -> Self

Create a image view.