MenuItem

Struct MenuItem 

pub struct MenuItem { /* private fields */ }
Represents an option within a Menu. They will always have an associated action that will be executed when activated.

Remark

This type is managed by nappgui itself. Rust does not have its ownership. When the menu object is dropped, all components assciated with it will be automatically released.

Implementations

Source

impl MenuItem

pub fn new() -> Self

Create a new item for a menu.

pub fn new_separator() -> Self

Create a new separator for a menu.