Panel

Struct Panel 

pub struct Panel { /* private fields */ }
A Panel is a control within a window that groups other controls. It defines its own reference system, that is, if we move a panel all its descendants will move in unison since their locations will be relative to its origin. It will support other (sub)-panels as descendants, which allows to form a Window Hierarchy. A Panel is a control within a window that groups other controls.

Remark

This type is managed by nappgui itself. Rust does not have its ownership. When the window object is dropped, all components assciated with it will be automatically released.

Implementations

Source

impl Panel

pub fn new() -> Self

Create a panel.

pub fn new_scroll(hscroll: bool, vscroll: bool) -> Self

Create a panel with scroll bars.

pub fn new_custom(hscroll: bool, vscroll: bool, border: bool) -> Self

Create a fully configurable panel.