SliderTrait

Trait SliderTrait 

pub trait SliderTrait {
    // Required method
    fn as_ptr(&self) -> *mut Slider;

    // Provided methods
    fn on_moved<F>(&self, handler: F)
       where F: FnMut(&EvSlider) + 'static { ... }
    fn tooltip(&self, text: &str) { ... }
    fn steps(&self, steps: u32) { ... }
    fn value(&self, value: f32) { ... }
    fn get_value(&self) -> f32 { ... }
}
The slider trait.

Required Methods

fn as_ptr(&self) -> *mut Slider

Returns a raw pointer to the slider object.

Provided Methods

fn on_moved<F>(&self, handler: F)
where F: FnMut(&EvSlider) + 'static,

Set an event handler for slider movement.

fn tooltip(&self, text: &str)

Set a tooltip for the slider. It is a small explanatory text that will appear when the mouse is over the control.

fn steps(&self, steps: u32)

Changes the slider from continuous range to discrete intervals.

fn value(&self, value: f32)

Set the slider position.

fn get_value(&self) -> f32

Get the slider position.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors