macro_rules! dbind {
($struct: ty, $field: ident, $field_type: ty, $bind_type: literal) => { ... };
}Expand description
Adds a field from a structure to its internal table within DBind.
macro_rules! dbind {
($struct: ty, $field: ident, $field_type: ty, $bind_type: literal) => { ... };
}Adds a field from a structure to its internal table within DBind.