macro_rules! dbind_increment {
($struct: ty, $field: ident, $increment: literal) => { ... };
}Expand description
Sets the increment of a numeric value, for example, when clicking an UpDown control.
macro_rules! dbind_increment {
($struct: ty, $field: ident, $increment: literal) => { ... };
}Sets the increment of a numeric value, for example, when clicking an UpDown control.