macro_rules! layout_dbind_obj {
($layout: expr, $obj: expr, $type: ty) => { ... };
}Expand description
Associate an object with a layout to view and edit it.
macro_rules! layout_dbind_obj {
($layout: expr, $obj: expr, $type: ty) => { ... };
}Associate an object with a layout to view and edit it.