pub struct ImageView { /* private fields */ }Expand description
ImageView are specialized views in visualizing images and GIF animations.
Remark
This type is managed by nappgui itself. Rust does not have its ownership. When the window object is dropped, all components assciated with it will be automatically released.
Implementations