pub struct MenuItem { /* private fields */ }Expand description
Represents an option within a Menu. They will always have an associated action that will be executed when activated.
Remark
This type is managed by nappgui itself. Rust does not have its ownership. When the menu object is dropped, all components assciated with it will be automatically released.
Implementations